********************************************
Welcome to thorns' and waves' documentation!
********************************************

.. module:: thorns
   :synopsis: Spike analysis software
.. moduleauthor:: Marek Rudnicki


The module is available at https://github.com/mrkrd/thorns


.. toctree::
   :maxdepth: 2

   api



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
